ardt.datasets.AERTrial
======================

.. currentmodule:: ardt.datasets

.. autoclass:: AERTrial

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~AERTrial.__init__
      ~AERTrial.get_signal_metadata
      ~AERTrial.load_ground_truth
      ~AERTrial.load_preprocessed_signal_data
      ~AERTrial.load_signal_data
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~AERTrial.dataset
      ~AERTrial.expected_response
      ~AERTrial.media_id
      ~AERTrial.media_name
      ~AERTrial.participant_id
      ~AERTrial.signal_data_files
      ~AERTrial.signal_preprocessors
      ~AERTrial.signal_types
   
   